==> jc-1.4.0.tar.gz: jas/DoubleCP.h <==
// public class jas.DoubleCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 2a2b21d40c8be58a jas_DoubleCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_DoubleCP_H_
#define _JC_jas_DoubleCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_DoubleCP$sub_refs	_jc_jas_DoubleCP$sub_refs;
typedef struct _jc_jas_DoubleCP$sub_nonrefs	_jc_jas_DoubleCP$sub_nonrefs;
typedef struct _jc_jas_DoubleCP$refs	_jc_jas_DoubleCP$refs;
typedef struct _jc_jas_DoubleCP$nonrefs	_jc_jas_DoubleCP$nonrefs;
typedef struct _jc_jas_DoubleCP$object	_jc_jas_DoubleCP$object;

typedef const struct _jc_jas_DoubleCP$vmethods	_jc_jas_DoubleCP$vmethods;
typedef const struct _jc_jas_DoubleCP$vtable	_jc_jas_DoubleCP$vtable;
typedef const struct _jc_jas_DoubleCP$vtype	_jc_jas_DoubleCP$vtype;

// Constructors
extern void _jc_jas_DoubleCP$method$_init$150bab920ca55717(_jc_env *, struct _jc_jas_DoubleCP$object *, jdouble);

// Virtual methods
extern void _jc_jas_DoubleCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_DoubleCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_DoubleCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_DoubleCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_DoubleCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_DoubleCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_DoubleCP$vmethods	jas_DoubleCP;
};

// Vtype
struct _jc_jas_DoubleCP$vtype {
	_jc_type			type;
	_jc_jas_DoubleCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_DoubleCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_DoubleCP$refs {
    _jc_jas_DoubleCP$sub_refs	jas_DoubleCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_DoubleCP$sub_nonrefs {
	jdouble	val;
};

// Non-reference instance fields (object)
struct _jc_jas_DoubleCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_DoubleCP$sub_nonrefs	jas_DoubleCP;
};

// Object instance structure
struct _jc_jas_DoubleCP$object {
	_jc_jas_DoubleCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_DoubleCP$vtype	*vtype;
	_jc_jas_DoubleCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_DoubleCP$vtype _jc_jas_DoubleCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_DoubleCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_DoubleCP$class_object;

#endif	/* _JC_jas_DoubleCP_H_ */

==> jc-1.4.6.tar.gz: jas/DoubleCP.h <==
// public class jas.DoubleCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class 2a2b21d40c8be58a jas_DoubleCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_DoubleCP_H_
#define _JC_jas_DoubleCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_DoubleCP$sub_refs	_jc_jas_DoubleCP$sub_refs;
typedef struct _jc_jas_DoubleCP$sub_nonrefs	_jc_jas_DoubleCP$sub_nonrefs;
typedef struct _jc_jas_DoubleCP$refs	_jc_jas_DoubleCP$refs;
typedef struct _jc_jas_DoubleCP$nonrefs	_jc_jas_DoubleCP$nonrefs;
typedef struct _jc_jas_DoubleCP$object	_jc_jas_DoubleCP$object;

typedef const struct _jc_jas_DoubleCP$vmethods	_jc_jas_DoubleCP$vmethods;
typedef const struct _jc_jas_DoubleCP$vtable	_jc_jas_DoubleCP$vtable;
typedef const struct _jc_jas_DoubleCP$vtype	_jc_jas_DoubleCP$vtype;

// Constructors
extern void _jc_jas_DoubleCP$method$_init$150bab920ca55717(_jc_env *, struct _jc_jas_DoubleCP$object *, jdouble) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_DoubleCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_DoubleCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_DoubleCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_DoubleCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_DoubleCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_DoubleCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_DoubleCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_DoubleCP$vmethods	jas_DoubleCP;
};

// Vtype
struct _jc_jas_DoubleCP$vtype {
	_jc_type			type;
	_jc_jas_DoubleCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_DoubleCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_DoubleCP$refs {
    _jc_jas_DoubleCP$sub_refs	jas_DoubleCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_DoubleCP$sub_nonrefs {
	jdouble	val;
};

// Non-reference instance fields (object)
struct _jc_jas_DoubleCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_DoubleCP$sub_nonrefs	jas_DoubleCP;
};

// Object instance structure
struct _jc_jas_DoubleCP$object {
	_jc_jas_DoubleCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_DoubleCP$vtype	*vtype;
	_jc_jas_DoubleCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_DoubleCP$vtype _jc_jas_DoubleCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_DoubleCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_DoubleCP$class_object;

#endif	/* _JC_jas_DoubleCP_H_ */
